Hemlock-REST
============

Hemlock REST Server.  Same functionality as the [Hemlock CLI](https://github.com/Lab41/Hemlock/blob/master/docs/CLI.md), but through a
[RESTful](https://github.com/Lab41/Hemlock-REST/blob/master/docs/REST.md) interface.

![Hemlock L](https://raw.github.com/Lab41/Hemlock-REST/master/docs/images/logo.png "Hemlock")

Install instructions
====================

Required dependencies
---------------------

[Hemlock](https://lab41.github.io/Hemlock/)

Python modules:
- [web](http://webpy.org/)

Running
----------

```bash
python rest-server.py 80
```
Alternatively, ``rest-server.py`` can be modified to support more robust
webservers.


Related repositories
--------------------

- [Hemlock](https://lab41.github.io/Hemlock/)

Contributing
============

What to contribute?  Awesome!  Issue a pull request or see more details [here](https://github.com/Lab41/Hemlock-REST/blob/master/CONTRIBUTING.md).
